@@ -2,6 +2,7 @@
     Contains the general methods for manipulating directories.
 '''
 # import json
+import ftputil
 from re import search
 import time
 import json
@@ -22,10 +23,18 @@ _THREAD_GET_FILES_ARRAY = []
 # todo - DOCUMENTATION FOR METHODS
 
 
-def create(path, dir_name=False):
+def create(path, dir_name=False, ftp=None):
+
     if dir_name is not False:
         path = os.path.join(path, dir_name)
 
+    if ftp is not None:
+        try:
+            if ftp.path.exists(path) is False:
+                ftp.makedirs(os.path.dirname(path))
+        except ftputil.error.PermanentError as error:
+            print(f"error: {str(error)}")
+
     if exists(path) is False:
         Path(path).mkdir(parents=True, exist_ok=True)
         # os.mkdir(path)
