@@ -851,10 +851,16 @@ def gen_relative_path(src_base, dst_base, file_path):
     if src_base == dst_base:
         print("src_base is identical to dst_base")
         return relative_path
+
     if src_base not in file_path and dst_base not in file_path:
         print("The file path must originate from either the src_path or dst_path.")
         return relative_path
 
+    if src_base in file_path:
+        relative_path = file_path.replace(dst_base, "")
+    if dst_base in file_path:
+        relative_path = file_path.replace(dst_base, "")
+
     if src_len > dst_len:
         dst_pos = file_path.lower().find(dst_base.lower())
         if dst_pos != -1:
@@ -874,6 +880,7 @@ def gen_relative_path(src_base, dst_base, file_path):
                 relative_path = file_path[len(src_base):]
             else:
                 relative_path = file_path[src_pos:]
+
     if relative_path is not None:
         relative_path = relative_path.replace(dst_base, "")
         relative_path = relative_path.replace(src_base, "")
@@ -983,8 +990,8 @@ def gen_src_path(src_base, dst_base, file_path):
 
 # src = r"C:/Users/Colemen/Desktop/TEST_FOLDER/Mnemosyne Tests/sourceDirectory/rendering"
 # dst = r"/mnemosyne_sync_test"
-# file_path = r"C:\Users\Colemen\Desktop\TEST_FOLDER\Mnemosyne Tests\sourceDirectory\rendering\20211029151612812.jpg"
-# print(gen_relative_path(src, dst, file_path))
+# file_path = r"C:\Users\Colemen\Desktop\TEST_FOLDER\Mnemosyne Tests\sourceDirectory\rendering\test folder\20211030011919612.jpg"
+# print("relative path: ", gen_relative_path(src, dst, file_path))
 # print("destination path: ", gen_dst_path(src, dst, file_path))
 # print("source path: ", gen_src_path(src, dst, file_path))
 # _copy_files_from_array([{"src_path": src, "dst_path": dst}])
